#
# spec file for package simh
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           simh
BuildRequires:  dos2unix
BuildRequires:  libpcap-devel
BuildRequires:  libvdeplug-devel
BuildRequires:  unzip
URL:            http://simh.trailing-edge.com/
Version:        3.12_5
Release:        1.2
Summary:        A collection of simulators of historically significant data processing systems
License:        BSD-3-Clause
Group:          System/Emulators/Other
Source:         http://simh.trailing-edge.com/sources/simhv312-5.zip
Patch1:         0001-Fix-const-declaration.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  help2man

%description
This package contains simulators of the following systems:
Data General Nova
Data General Eclipse
Digital Equipment Corporation PDP-1
Digital Equipment Corporation PDP-4
Digital Equipment Corporation PDP-7
Digital Equipment Corporation PDP-8
Digital Equipment Corporation PDP-9
Digital Equipment Corporation PDP-10
Digital Equipment Corporation PDP-11
Digital Equipment Corporation PDP-15
Digital Equipment Corporation PDP-18B
IBM 1401
IBM System 3
Hewlett-Packard HP 2100
Honeywell H316
MITS Altair 8800

A disk image with UNIX V7 for the PDP-11 is included, instructions on
how to make it work can be found in the file
/usr/share/doc/packages/simh/simh_swre.txt in chapter 2.1.3.

A selection of software for other systems can be found at The Computer
History Simulation Project at http://simh.trailing-edge.com/

%prep
%setup -c -T
unzip -a %SOURCE0
cd sim
%patch -P 1 -p1

%build
cd sim
mkdir -p BIN
make
for i in $(cd BIN; ls * | grep -v buildtools) ; do
	mv -v BIN/${i} BIN/simh-${i}
done

cp sim_rev.h CHANGELOG_sim_rev_h.txt

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/usr/bin
install -m 755 sim/BIN/simh-* $RPM_BUILD_ROOT/usr/bin
chmod 644 sim/*.txt sim/SDS/*.txt sim/Interdata/*.txt
for i in sim/*.txt sim/*/*.txt ; do
  dos2unix ${i}
done

%files
%defattr(-,root,root)
%doc sim/*.txt sim/*/*txt
%{_bindir}/simh-*

%changelog
* Tue Sep 24 2024 Klaus Kämpf <kkaempf@suse.de>
- This release is mostly bug fixes, particularly in the PDP-11 and
  Sigma simulators. Chaosnet support has been added to the PDP-10 and
  PDP-11.
  See the detailed revision histories in individual source code
  modules for details.
- drop 0001-declare-don-t-define-uc15_memsize-in-include-file.patch,
  upstreamed
- add 0001-Fix-const-declaration.patch
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Jun 23 2023 Klaus Kämpf <kkaempf@suse.com>
- Update to 3.12_4
  This release is mostly bug fixes, particularly in the PDP-11 and
  Sigma simulators.
  Support for running SimH on MacOS "Classic" (pre-OSX) and OS/2
  has been dropped.
  See the detailed revision histories in individual source code
  modules for details.
  * simh-s3 got dropped upstream
* Sun Jun  7 2020 Klaus Kämpf <kkaempf@suse.com>
- Update to 3.11
  V3.11 incorporates SCP additions and extensions by Dave Bryan to
  support his HP simulators.
  * added simh-sigma and simh-uc15
- dropped Unix v7 image, get it from http://simh.trailing-edge.com/software.html
- add 0001-declare-don-t-define-uc15_memsize-in-include-file.patch
- dropped interim-20130422.tar.gz and interim-20130422.patch
  (removed simh-altairz80, simh-hp2100, simh-swtp6800mp-a, simh-swtp6800mp-a2)
- dropped (unused) simhv37-3.dif
- Update to 3.10
  V3.10 backports an significant number of modules and features from
  the SimH 4.x branch, as well as some unique new features.
* Mon Apr 22 2013 boris@steki.net
- Updated to latest upstream 39_0 version
  a lot of changes please look at CHANGELOG_simh_rev_h.txt in
  /usr/share/doc/packages/simh
- Interim source fixes attached ( interim-20130422.patch )
- Use source url for zip
* Mon Apr 22 2013 speilicke@suse.com
- Rename binary "nova" to "simh.nova" to avoid file conflict with
  python-novaclient (from OpenStack)
* Sun Aug 23 2009 meissner@suse.de
- make it build with --as-needed
* Tue Apr 15 2008 kkaempf@suse.de
- update to v37-3
  bugfix update, see http://simh.trailing-edge.com/changes37.html
  for details.
* Thu Aug  2 2007 kkaempf@suse.de
- update to v37-2
  bugfix update, see http://simh.trailing-edge.com/changes37.html
  for details.
- enable network support.
* Thu Mar 29 2007 kkaempf@suse.de
- unzip is required during build.
* Tue Feb  6 2007 kkaempf@suse.de
- update to 3.7
  added VAX780 emulation.
  See http://simh.trailing-edge.com/changes34.html,
  http://simh.trailing-edge.com/changes35.html,
  http://simh.trailing-edge.com/changes36.html,
  http://simh.trailing-edge.com/changes37.html
  for the complete list of changes since 3.3
* Thu Apr  6 2006 hvogel@suse.de
- define operation on "i" [#160437]
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 25 2005 kkaempf@suse.de
- update to 3.3_1
  lots of fixes for HP2100
  see http://simh.trailing-edge.com/changes33.html for details.
* Fri Aug 13 2004 kkaempf@suse.de
- rename /usr/bin/eclipse to /usr/bin/simh-eclipse, the package
  eclipse already claimed the initial name.
- provide more .txt files as documentation.
* Tue Aug 10 2004 kkaempf@suse.de
- update to 3.2.2
  added LGP-30 (LGP-31) simulator
  see http://simh.trailing-edge.com/changes32.html for details
* Tue Feb  3 2004 kkaempf@suse.de
- update to 3.1-0
  lots of changes, see http://simh.trailing-edge.com/changes30.html
  and http://simh.trailing-edge.com/changes31.html for details
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Fri Jul 25 2003 coolo@suse.de
- use BuildRoot
* Tue Jun 17 2003 kkaempf@suse.de
- update to 2.10-4
  includes all systems in a single .zip file now
  enhanced magtape emulation, .ini file support, line frequency
  clocks, and more.
- compile properly on 32bit archs
* Wed Jan  8 2003 kkaempf@suse.de
- update to 2.10-1
  Added simulators for SDS 940, Interdata (Perkin-Elmer) 16b/32b,
  IBM 1130, IBM 1620, GRI 909
  Further features:
  Telnet console capability, removed VT emulation; DO with
  substitutable arguments; quiet mode; device enable/disable
  support optional simulator for input, output, commands;
  PDP-11 KW11P programmable clock; PDP-11 RK611/RK06/RK07 disk
  PDP-11/VAX TMSCP tape; PDP-11/VAX DELQA Ethernet support
  (from David Hittner); PDP-11/PDP-10 RX211/RX02 floppy disk;
  PDP-11/VAX autoconfiguration support; PDP-10/PDP-11/VAX variable
  vector support; PDP-1 DECtape; PDP-8 RX28 support; HP2100 12845A
  line printer; HP2100 13183 magtape support; HP2100 boot ROM
  support; 16b DECtape file format support; support for statically
  buffered devices; magtape end of medium support; 7B/8B support to
  terminals and multiplexors
* Thu Jun 13 2002 uli@suse.de
- update -> 2.9-10 (All simulators: Widened the POS register for
  serial devices to 32b; PDP11: fixed bugs, added special case for
  PS<15:12> = 1111 to MFPI, removed from MTPI, added masking of
  relocation adds; 1401: added hardware multiply/divide, added 1311
  disk pack, added 1401-like memory dump, fixed bugs, 8 character N
  is legal, 5 and 7 character H are legal, 7 character  H doesn't
  branch)
* Tue Jun  4 2002 uli@suse.de
- update -> 2.9-9 (VAX!)
* Wed Feb 27 2002 uli@suse.de
- made some docs non-world-writable
* Fri Jan 25 2002 uli@suse.de
- initial package
